@@ -35,4 +35,4 @@ def mq_consumer(DB_django_task_mq,fun,topic):
             finally:
                 mq.delete()
                 print('[OVER]:',mq.id,mq.topic,mq.message)
-        else: print('none task...')
\ No newline at end of file
+        else:pass
\ No newline at end of file
